"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.useFadeAnimation = void 0;

var _react = _interopRequireDefault(require("react"));

var _Box = _interopRequireDefault(require("../../primitives/Box"));

var _usePropsConfig = require("../../../hooks/usePropsConfig");

var _reactNative = require("react-native");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const useFadeAnimation = (duration = 500, initValue = 0, finalValue = 1) => {
  const fadeValue = _react.default.useRef(new _reactNative.Animated.Value(0)).current;

  const fadeIn = () => {
    _reactNative.Animated.timing(fadeValue, {
      toValue: finalValue,
      duration: duration,
      useNativeDriver: _reactNative.Platform.OS !== 'web'
    }).start();
  };

  const fadeOut = () => {
    _reactNative.Animated.timing(fadeValue, {
      toValue: initValue,
      duration: duration,
      useNativeDriver: _reactNative.Platform.OS !== 'web'
    }).start();
  };

  return {
    fadeValue,
    fadeIn,
    fadeOut
  };
};

exports.useFadeAnimation = useFadeAnimation;

const Fade = ({
  children,
  ...props
}) => {
  const {
    in: animationState,
    duration
  } = (0, _usePropsConfig.usePropsConfig)('Fade', props);
  const {
    fadeValue,
    fadeIn,
    fadeOut
  } = useFadeAnimation(duration);
  animationState ? fadeIn() : fadeOut();
  return /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: {
      opacity: fadeValue
    }
  }, /*#__PURE__*/_react.default.createElement(_Box.default, props), children);
};

var _default = Fade;
exports.default = _default;
//# sourceMappingURL=Fade.js.map