"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _Transitions = require("../../components/composites/Transitions");

var _Context = require("./Context");

var _Box = _interopRequireDefault(require("../../components/primitives/Box"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const Overlay = ({
  children,
  disableOverlay,
  position,
  animationDuration,
  defaultBackgroundColor,
  closeOnPress
}) => {
  const [overlayItem, setOverlayItem] = _react.default.useState(null);

  const [config, setConfig] = _react.default.useState({
    disableOverlay: disableOverlay,
    position: position || 'center',
    backgroundColor: defaultBackgroundColor || '#161616cc',
    animationDuration: animationDuration || 500,
    closeOnPress: !closeOnPress ? false : true,
    onClose: _a => {}
  });

  const {
    fadeValue,
    fadeIn,
    fadeOut
  } = (0, _Transitions.useFadeAnimation)(animationDuration);

  let providerStyle = _reactNative.StyleSheet.create({
    provider: {
      position: 'absolute',
      top: 0,
      bottom: 0,
      right: 0,
      left: 0,
      zIndex: 999,
      alignItems: 'center',
      opacity: 0.5,
      // backgroundColor: config.disableOverlay
      //   ? 'transparent'
      //   : config.backgroundColor,
      justifyContent: config.position === 'top' ? 'flex-start' : config.position === 'bottom' ? 'flex-end' : 'center'
    }
  });

  const pointerEventsSetter = () => {
    if (overlayItem) {
      return config.disableOverlay ? 'box-none' : 'auto';
    } else {
      return 'none';
    }
  };

  overlayItem ? fadeIn() : fadeOut();
  return (
    /*#__PURE__*/
    // Need to use React native view to apply pointerEvents none
    _react.default.createElement(_Context.OverlayContext.Provider, {
      value: {
        setOverlayItem,
        defaultConfig: config,
        setConfig
      }
    }, children, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
      nativeID: "toast-provider",
      style: [providerStyle.provider, {
        opacity: fadeValue
      }],
      pointerEvents: pointerEventsSetter()
    }, /*#__PURE__*/_react.default.createElement(_Box.default, {
      w: "100%",
      h: "100%",
      zIndex: 999999
    }, overlayItem), /*#__PURE__*/_react.default.createElement(_Box.default, {
      bg: config.disableOverlay ? 'transparent' : config.backgroundColor ? config.backgroundColor : '#161616cc',
      style: providerStyle.provider
    }), config.closeOnPress ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      style: [providerStyle.provider, {
        backgroundColor: 'transparent'
      }],
      onPress: () => {
        setOverlayItem(null);
        config.onClose ? config.onClose(false) : null;
      }
    }) : null))
  );
};

var _default = Overlay;
exports.default = _default;
//# sourceMappingURL=OverlayProvider.js.map