import React from 'react';
import { Animated, StyleSheet, TouchableOpacity } from 'react-native';
import { useFadeAnimation } from '../../components/composites/Transitions';
import { OverlayContext } from './Context';
import Box from '../../components/primitives/Box';

const Overlay = ({
  children,
  disableOverlay,
  position,
  animationDuration,
  defaultBackgroundColor,
  closeOnPress
}) => {
  const [overlayItem, setOverlayItem] = React.useState(null);
  const [config, setConfig] = React.useState({
    disableOverlay: disableOverlay,
    position: position || 'center',
    backgroundColor: defaultBackgroundColor || '#161616cc',
    animationDuration: animationDuration || 500,
    closeOnPress: !closeOnPress ? false : true,
    onClose: _a => {}
  });
  const {
    fadeValue,
    fadeIn,
    fadeOut
  } = useFadeAnimation(animationDuration);
  let providerStyle = StyleSheet.create({
    provider: {
      position: 'absolute',
      top: 0,
      bottom: 0,
      right: 0,
      left: 0,
      zIndex: 999,
      alignItems: 'center',
      opacity: 0.5,
      // backgroundColor: config.disableOverlay
      //   ? 'transparent'
      //   : config.backgroundColor,
      justifyContent: config.position === 'top' ? 'flex-start' : config.position === 'bottom' ? 'flex-end' : 'center'
    }
  });

  const pointerEventsSetter = () => {
    if (overlayItem) {
      return config.disableOverlay ? 'box-none' : 'auto';
    } else {
      return 'none';
    }
  };

  overlayItem ? fadeIn() : fadeOut();
  return (
    /*#__PURE__*/
    // Need to use React native view to apply pointerEvents none
    React.createElement(OverlayContext.Provider, {
      value: {
        setOverlayItem,
        defaultConfig: config,
        setConfig
      }
    }, children, /*#__PURE__*/React.createElement(Animated.View, {
      nativeID: "toast-provider",
      style: [providerStyle.provider, {
        opacity: fadeValue
      }],
      pointerEvents: pointerEventsSetter()
    }, /*#__PURE__*/React.createElement(Box, {
      w: "100%",
      h: "100%",
      zIndex: 999999
    }, overlayItem), /*#__PURE__*/React.createElement(Box, {
      bg: config.disableOverlay ? 'transparent' : config.backgroundColor ? config.backgroundColor : '#161616cc',
      style: providerStyle.provider
    }), config.closeOnPress ? /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: [providerStyle.provider, {
        backgroundColor: 'transparent'
      }],
      onPress: () => {
        setOverlayItem(null);
        config.onClose ? config.onClose(false) : null;
      }
    }) : null))
  );
};

export default Overlay;
//# sourceMappingURL=OverlayProvider.js.map